@@ -214,6 +214,10 @@ int main() {
                 "\tPSP SOSDRV: %ld\n\n",
                 fw_information.fw_info_list[amdsmi_fw_block_t::AMDSMI_FW_ID_PSP_SOSDRV]
                     .fw_version);
+            printf(
+                "\tPLDM BUNDLE: %ld\n\n",
+                fw_information.fw_info_list[amdsmi_fw_block_t::AMDSMI_FW_ID_PLDM_BUNDLE]
+                    .fw_version);
 
             // Get temperature measurements
             int64_t temp_measurements[AMDSMI_TEMPERATURE_TYPE__MAX + 1];
